@@ -2,11 +2,6 @@
 from django.conf import settings as django_settings
 
 SETTINGS = (
-    {
-        'name': 'HIJACK_DISPLAY_ADMIN_BUTTON',
-        'default': True,
-        'legacy_name': 'SHOW_HIJACKUSER_IN_ADMIN',
-    },
     {
         'name': 'HIJACK_DISPLAY_WARNING',
         'default': True,
@@ -27,6 +22,11 @@ SETTINGS = (
         'default': False,
         'legacy_name': 'ALLOW_STAFF_TO_HIJACK_STAFF_USER',
     },
+    {
+        'name': 'HIJACK_ALLOW_GET_REQUESTS',
+        'default': False,
+        'legacy_name': None,
+    },
     {
         'name': 'HIJACK_LOGIN_REDIRECT_URL',
         'default': getattr(django_settings, 'LOGIN_REDIRECT_URL', '/'),
@@ -52,12 +52,6 @@ SETTINGS = (
         'default': False,
         'legacy_name': None,
     },
-    {
-        'name': 'HIJACK_BUTTON_TEMPLATE',
-        'default': 'hijack/admin_button.html',
-        'legacy_name': None,
-    },
-
 )
 
 for setting in SETTINGS:
