@@ -34,14 +34,19 @@ PASSWORD_HASHERS = ('django.contrib.auth.hashers.PBKDF2PasswordHasher',
                     'django.contrib.auth.hashers.MD5PasswordHasher',
                     'django.contrib.auth.hashers.CryptPasswordHasher', )
 
-MIDDLEWARE_CLASSES = (
+MIDDLEWARE = (
+    'django.middleware.security.SecurityMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.common.CommonMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
-    # 'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
+    'django.contrib.messages.middleware.MessageMiddleware',
+    'django.middleware.clickjacking.XFrameOptionsMiddleware',
+    'hijack.middleware.HijackRemoteUserMiddleware',
 )
 
+MIDDLEWARE_CLASSES = MIDDLEWARE
+
 TEMPLATE_CONTEXT_PROCESSORS = (
     "django.contrib.auth.context_processors.auth",
     "django.core.context_processors.debug",
@@ -50,7 +55,28 @@ TEMPLATE_CONTEXT_PROCESSORS = (
     "django.core.context_processors.static",
     "django.core.context_processors.tz",
     "django.contrib.messages.context_processors.messages",
-    'django.core.context_processors.request', )
+    'django.core.context_processors.request',
+)
+
+TEMPLATES = [
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': TEMPLATE_DIRS,
+        'APP_DIRS': True,
+        'OPTIONS': {
+            'context_processors': [
+                "django.contrib.auth.context_processors.auth",
+                "django.template.context_processors.debug",
+                "django.template.context_processors.i18n",
+                "django.template.context_processors.media",
+                "django.template.context_processors.static",
+                "django.template.context_processors.tz",
+                "django.contrib.messages.context_processors.messages",
+                'django.template.context_processors.request',
+            ],
+        },
+    },
+]
 
 EXTERNAL_APPS = [
     'django.contrib.admin',
@@ -74,4 +100,4 @@ SECRET_KEY = 'foobar'
 
 LANGUAGE_CODE = 'en-us'
 USE_I18N = True
-USE_L10N = True
\ No newline at end of file
+USE_L10N = True
