@@ -16,20 +16,14 @@ from hijack.tests import test_settings
 if not settings.configured:
     settings.configure(**test_settings.__dict__)
 
-#  from django_coverage.coverage_runner import CoverageRunner
 from django_nose import NoseTestSuiteRunner
 
 
-class NoseCoverageTestRunner(NoseTestSuiteRunner):
-    """Custom test runner that uses nose and coverage"""
-    pass
-
-
 def runtests(*test_args):
     import django
     if django.VERSION >= (1, 7):
         django.setup()
-    failures = NoseCoverageTestRunner(verbosity=2,
+    failures = NoseTestSuiteRunner(verbosity=2,
                                       interactive=True).run_tests(test_args)
     sys.exit(failures)
 
